==> mqtt_client-1.1.0.tar.gz: lib/src/connectionhandling/mqtt_client_mqtt_connection_keep_alive.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 22/06/2017
 * Copyright :  S.Hamblett
 */

part of mqtt_client;

/// Implements keepalive functionality on the Mqtt Connection, ensuring that the connection
/// remains active according to the keepalive seconds setting.
/// This class implements the keepalive by sending an MqttPingRequest to the broker if a message
/// has not been send or received within the keepalive period.
class MqttConnectionKeepAlive {
  /// Initializes a new instance of the MqttConnectionKeepAlive class.
  MqttConnectionKeepAlive(IMqttConnectionHandler connectionHandler,
      int keepAliveSeconds) {
    this._connectionHandler = connectionHandler;
    this.keepAlivePeriod = keepAliveSeconds * 1000;
    // Register for message handling of ping request and response messages.
    connectionHandler.registerForMessage(
        MqttMessageType.pingRequest, pingRequestReceived);
    connectionHandler.registerForMessage(
        MqttMessageType.pingResponse, pingResponseReceived);
    connectionHandler.registerForAllSentMessages(messageSent);
    // Start the timer so we do a ping whenever required.
    pingTimer = new Timer(
        new Duration(milliseconds: this.keepAlivePeriod),
        pingRequired);
  }

  /// The keep alive period in  milliseconds
  int keepAlivePeriod;

  /// The timer that manages the ping callbacks.
  Timer pingTimer;

  IMqttConnectionHandler _connectionHandler;

  /// Used to synchronise shutdown and ping operations.
  bool _shutdownPadlock = false;

  /// Pings the message broker if there has been no activity for the specified amount of idle time.
  void pingRequired() {
    if (_shutdownPadlock) {
      return;
    } else {
      _shutdownPadlock = true;
    }
    final MqttPingRequestMessage pingMsg = new MqttPingRequestMessage();
    _connectionHandler.sendMessage(pingMsg);
    pingTimer = new Timer(
        new Duration(milliseconds: this.keepAlivePeriod),
        pingRequired);
    _shutdownPadlock = false;
  }

  /// Signal to the keepalive that a ping request has been received from the message broker.
  /// The effect of calling this method on the keepalive handler is the transmission of a ping response
  /// message to the message broker on the current connection.
  bool pingRequestReceived(MqttMessage pingMsg) {
    if (_shutdownPadlock) {
      return false;
    } else {
      _shutdownPadlock = true;
    }
    final MqttPingResponseMessage pingMsg = new MqttPingResponseMessage();
    _connectionHandler.sendMessage(pingMsg);
    _shutdownPadlock = false;
    return true;
  }

  /// Processed ping response messages received from a message broker.
  bool pingResponseReceived(MqttMessage pingMsg) {
    return true;
  }

  /// Handles the MessageSent event of the connectionHandler control.
  bool messageSent(MqttMessage msg) {
    return true;
  }

  /// Stop the keep alive process
  void stop() {
    pingTimer.cancel();
  }
}

==> mqtt_client-1.9.1.tar.gz: lib/src/connectionhandling/mqtt_client_mqtt_connection_keep_alive.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 22/06/2017
 * Copyright :  S.Hamblett
 */

part of mqtt_client;

/// Implements keepalive functionality on the Mqtt Connection, ensuring that the connection
/// remains active according to the keepalive seconds setting.
/// This class implements the keepalive by sending an MqttPingRequest to the broker if a message
/// has not been send or received within the keepalive period.
class MqttConnectionKeepAlive {
  /// Initializes a new instance of the MqttConnectionKeepAlive class.
  MqttConnectionKeepAlive(IMqttConnectionHandler connectionHandler,
      int keepAliveSeconds) {
    this._connectionHandler = connectionHandler;
    this.keepAlivePeriod = keepAliveSeconds * 1000;
    // Register for message handling of ping request and response messages.
    connectionHandler.registerForMessage(
        MqttMessageType.pingRequest, pingRequestReceived);
    connectionHandler.registerForMessage(
        MqttMessageType.pingResponse, pingResponseReceived);
    connectionHandler.registerForAllSentMessages(messageSent);
    // Start the timer so we do a ping whenever required.
    pingTimer = new Timer(
        new Duration(milliseconds: this.keepAlivePeriod), pingRequired);
  }

  /// The keep alive period in  milliseconds
  int keepAlivePeriod;

  /// The timer that manages the ping callbacks.
  Timer pingTimer;

  /// The connection handler
  MqttConnectionHandler _connectionHandler;

  /// Used to synchronise shutdown and ping operations.
  bool _shutdownPadlock = false;

  /// Pings the message broker if there has been no activity for the specified amount of idle time.
  void pingRequired() {
    if (_shutdownPadlock) {
      return;
    } else {
      _shutdownPadlock = true;
    }
    final MqttPingRequestMessage pingMsg = new MqttPingRequestMessage();
    if (_connectionHandler.connectionState == ConnectionState.connected) {
      _connectionHandler.sendMessage(pingMsg);
    }
    pingTimer = new Timer(
        new Duration(milliseconds: this.keepAlivePeriod), pingRequired);
    _shutdownPadlock = false;
  }

  /// Signal to the keepalive that a ping request has been received from the message broker.
  /// The effect of calling this method on the keepalive handler is the transmission of a ping response
  /// message to the message broker on the current connection.
  bool pingRequestReceived(MqttMessage pingMsg) {
    if (_shutdownPadlock) {
      return false;
    } else {
      _shutdownPadlock = true;
    }
    final MqttPingResponseMessage pingMsg = new MqttPingResponseMessage();
    _connectionHandler.sendMessage(pingMsg);
    _shutdownPadlock = false;
    return true;
  }

  /// Processed ping response messages received from a message broker.
  bool pingResponseReceived(MqttMessage pingMsg) {
    return true;
  }

  /// Handles the MessageSent event of the connectionHandler control.
  bool messageSent(MqttMessage msg) {
    return true;
  }

  /// Stop the keep alive process
  void stop() {
    pingTimer.cancel();
  }
}
